body{
	background-color: #F5F5F5;
	font-family: Arial, Helvetica, sans-serif;
}

/* libraries */
#contentLibraries{
	border: 1px solid #C6C6C6;
	background-color: white;
	margin-left: 20px;
	margin-right: 20px;
	margin-top: 9px;	
}

#contentLibraries .library-icon
{
	float: left;
	background-color: white;
	height: 18px;
	padding: 11px 19px 10px 19px;
		display:block;
}

#contentLibraries li
{
	border-bottom: 1px solid #e2e2e2;
	position: relative;
	list-style: none;
}

#contentLibraries li:last-child
{
	border: none;
}

#contentLibraries .library-link
{
	width: 65%;
	height: 28px;
	border: none;
	padding: 11px 0 0 0px;
	background-color: white;
	display: block;
	float:left;
	font-family: Arial;
	font-size: 16px; 
	text-decoration: none;
	color: #525252 ;
	overflow: hidden;
}

 #contentLibraries a
{
	position: absolute;
	height: 39px;
	width: 100%;
	z-index: 10;
	display: block;
	top 0;
	text-decoration: none;
}

#contentLibraries .library-indicator
{
	float: right;
	background-color: white;
	height: 8px;
	padding: 16px 16px 15px 16px;
		display:block;
}


#content h1
{
	color: #292929;
	text-align: center;
	font-size: 21px;
}

#contentLibraries h1{
	color: #292929;
	text-align: center;
	border-bottom: 1px solid #C6C6C6;
	font-size: 21px;
	padding: 15px 0 16px 0;
}

#folder-header
{
	position: fixed;
	width: 100%;
	height: 88px;
	background-color: rgba(255,255,255,0.9);
	border-bottom: 1px solid #C6C6C6;
	z-index: 999;
}

#folder-subheader1
{
	width: 100%;
	height: 40px;
	margin-top: 18px;

}

#folder-subheader2
{
	width: 100%;
	padding-left: 16px;
}

#topIndex
{
	position: absolute;
	left: 16px;
	top: 19px;
}

#topIndex a
{
	float: left;
}

.indicator {
	margin: 0 5px;
}

.path {
	text-decoration: none;
	color: #5C5C5C;
	font-family: Arial, Helvetica;
	font-size: 15px;

}

#header-combos
{
	position: absolute;
	right: 10px;
	top: 15px;
	color: #a3a3a3;
	width: 160px;
}

#topIndex .next{
	width: 25px;
	height: 19px;
	border: none;
	margin: 0 21px 4px 0;
	padding: 5px 0 0 0;
	display: block;
	background: url("/images/next.png") no-repeat scroll 0 0 transparent;
	background-size: 25px 19px;
	padding: 0;
	text-indent: -99999px;
}

#topIndex .previous{
	width: 25px;
	height: 19px;
	border: none;
	margin: 0 14px 4px 0;
	padding: 5px 0 0 0;
	display: block;
	background: url("/images/prev.png") no-repeat scroll 0 0 transparent;
	background-size: 25px 19px;
	padding: 0;
	text-indent: -99999px;
}

#topIndex .up{
	width: 15px;
	height: 19px;
	border: none;
	background: url("/images/up.png") no-repeat scroll 0 0 transparent;
	background-size: 15px 19px;
	color: #FFF;
	display: block;
	text-indent: -99999px;	
}

#itemContainer li
{

height: 120px;
border: 1px solid #E2E2E2;
margin: 9px 10px 0px 10px;
background-color: white;
overflow: hidden;
position: relative;
}

.folderContent
{
	padding-top: 90px;
}
/* hasta aquí */

.folder
{
float: left;

}

.cover
{
float: left;
overflow: hidden;
}

.mark
{
	position: absolute;
	top: 0px;
	margin-left: 55px;
}

.info
{
padding: 8px 0px 0px 0px;

position: relative;
height: 115px;

padding-left: 82px;
}

.buttons
{
	position:absolute;
	bottom:0px;
	left:80px;
	right: 0px;
	border-top: 1px solid #e2e2e2;
	padding-top: 3px;
	height: 25px;
	font-family: Arial;
	color: #6e6e6e;
	font-size: 10px;
}

.elementInfo
{
	position:absolute;
	bottom:24px;
	padding-top: 3px;
	height: 25px;
	width: 100%;
	font-family: Arial;
	color: #adadad;
	font-size: 10px;
}

.numPages
{
	float: left;
	padding-left:8px;
}

.comicSize
{
	float: right;
	padding-right: 9px;
}



#itemContainer a
{
	text-decoration: none;

	
}

.browseButton
{
	width: 60px;
	background: url("/images/browse.png") no-repeat scroll 0 0 transparent;
	background-position: 1px 6px;
	background-size: 7px 7px;
	border: none;
	text-align:right;
	display: block;
	float: right;
	padding: 4px 10px 0 0;
	color: #6e6e6e;
}

.importButton
{
	width: 60px;
	background: url("/images/download.png") no-repeat scroll 0 0 transparent;
	background-position: 3px 5px;
	background-size: 7px 8px;
	border: none;
	text-align:left;
	display: block;
	float: left;
	margin: 0 0 0 4px;
	padding: 4px 0 0 16px;
	color: #6e6e6e;
}

.readButton
{
	width: 60px;
	background: url("/images/read.png") no-repeat scroll 0 0 transparent;
	background-position: 18px 5px;
	background-size: 7px 9px;
	border: none;
	text-align:right;
	display: block;
	float: right;
	padding: 4px 10px 0 0;
	color: #6e6e6e;
}

.importedButton
{
	width: 60px;
	background: url("/images/imported.png") no-repeat scroll 0 0 transparent;
	background-position: 2px 6px;
	background-size: 8px 6px;
	border: none;
	text-align:left;
	display: block;
	float: left;
	margin: 0 0 0 4px;
	padding: 4px 0 0 16px;
	color: #6e6e6e;
}


#indexes{
	border-top: 1px solid #C6C6C6;
	background-color: white;
	padding: 0px;
	margin: 9px 0 0 0;
}

.index{
	background-color: white;
	margin: 9px 0 9px 0;
}


#alphaIndex a, #pageIndex a{
	width: 29px;
	height: 24px;
	border: none;
	margin: 0 0 9px 9px;
	padding: 5px 0 0 0px;
	color: #5C5C5C;
	font-size: 20px;
	text-align: center;
	display: block;
	text-decoration: none;
	font-family: Arial;
	border: 1px solid #E2E2E2;
	text-align:center;
}

#alphaIndex li, #pageIndex li{
	float: left;
}

#pageIndex .current{
	color: white;
	background-color: #A2A2A2;
	border: 1px solid #A2A2A2;

}

	#content h2, #contentLibraries h2{
		color: #000;
		font-weight: bold;
		font-size: 12px;
		margin: 0 0 16px 0;
	}
	
	.inputs_login{
		width: 256px;
		height: 64px;
		background: url("/images/fnd_inputs.jpg") no-repeat scroll 0 0 #FFF;
		margin: 0 0 18px 0;
	}
		.username{
			width: 200px;
			height: 24px;
			background: url("/images/fnd_input_username.jpg") no-repeat scroll 0 0 #2b2b2b;
			border: none;
			padding: 0 0 0 44px;
			margin: 5px 0 6px 8px;
			font-size: 14px;
			color: #6e6e6e;
		}
		.pass{
			width: 200px;
			height: 24px;
			background: url("/images/fnd_input_pass.jpg") no-repeat scroll 0 0 #2b2b2b;
			border: none;
			padding: 0 0 0 44px;
			margin: 0 0 0 8px;
			font-size: 14px;
			color: #6e6e6e;
		}
		.button_sign{
			width: 86px;
			height: 30px;
			background: url("/images/bt_login.jpg") no-repeat scroll 0 0 transparent;
			border: none;
			margin: 0;
			padding: 0;
			color: #FFF;
			font-size: 14px;
			float: left;
		}
		.infor{
			color: #666;
			font-size: 8px;
			float: left;
			width: 112px;
			margin: 0 0 0 8px;
			line-height: 120%;
		}

.clear{
	height: 2px;
	clear: both;
}

.title{
	font-family: Arial;
	font-size: 12px;
	margin: 0 0 0 6px;
	color: #555555                                                                     ;
	overflow: hidden;
	word-wrap: break-word;
	height: 65px;
	text-decoration: none;
}

#indexalpha, #indexnumber{

    -webkit-appearance: none;
    background-color: rgba(255,255,255,0);
    border-radius: 0px;
    border: none;
    color: #a3a3a3;
    font-size: 16px;
    font-family: Arial, Helvetica;
    height: 30px;
    margin: 0 0 0 10px;
    padding:0;
   	float: right;
}

.comboIndicator {
	float: right;
	padding: 14px 0 0 0;
	margin: 0 0 0 4px;
	width: 5px;
}